import re

plot_functions = {
        'linesDots': {
            "description": (
                "Lines, one color dots. Dot or line/color mapping defined by "
                "ValueColors with available colors: RYGMCW.\n"
                "Ex: L:G|D:W\n"
                "  means \tLines are plotted with color G\n"
                "\tDots are plotted with color W\n"
                "If D is not defined, dots won't be displayed.\n"
                "If L is not defined, lines will be plotted with color G"),
            "plot_function": "plot_lines_dots",
            "value_pattern": re.compile('^(L|D|Line|Dot)$')
        },
        'linesSRate': {
            "description": "Lines, one color dots, bitweight info. ",
            "plot_function": "plot_lines_s_rate"
        },
        'linesMasspos': {
            "description": "multi-line mass position, multi-color dots. ",
            "plot_function": "plot_lines_mass_pos"
        },
        'triColorLines': {
            "description": "Three lines with three different colors for "
                           "values -1, 0, 1.",
            "plot_function": "plot_tri_colors",
            "value_pattern": re.compile('^-?[10]?$')
        },
        'dotForTime': {
            "description": (
                "Dots according to timestamp.\n"
                "Color defined by ValueColors with available colors: RYGMCW.\n"
                "Ex: G"),
            "plot_function": "plot_time_dots"
        },
        'multiColorDotsEqualOnUpperBound': {
            "description": (
                "Multicolor dots in center with value/colors mapping defined "
                "by ValueColors with available colors: RYGMCW.\n"
                "Value from low to high.\n"
                "Ex: *:W  in which all values represent by white dots.\n"
                "Ex: -1:_|0:R|2.3:Y|+2.3:G\n"
                "  in which \tvalue <= -1  => not plot\n"
                "\tvalue <= 0   => plot with R color\n"
                "\t0 < value <= 2.3 => plot with Y color\n"
                "\t2.3 < value  => plot with G color\n"),
            "plot_function": "plot_multi_color_dots_equal_on_upper_bound",
            "value_pattern": re.compile('^(\+|<=)?[0-9]+\.?[0-9]?<?$')  # noqa: W605,E501
        },
        'multiColorDotsEqualOnLowerBound': {
            "description": (
                "Multicolor dots in center with value/colors mapping defined "
                "by ValueColors with available colors: RYGMCW.\n"
                "Value from low to high.\n"
                "Ex: 3.:R|3.3:Y|=3.3:G\n"
                "  in which"
                "\tvalue < 3.   => plot with R color\n"
                "\t3. <= value < 3.3 => plot with Y color\n"
                "\tvalue = 3.3  => plot with G color\n"),
            "plot_function": "plot_multi_color_dots_equal_on_lower_bound",
            "value_pattern": re.compile('^[=<]?[0-9]\.?[0-9]?$')  # noqa: W605
        },
        'upDownDots': {
            "description": (
                "Show data with 2 different values: first down/ second up. "
                "Colors defined by ValueColors.\nEx: 1:R|0:Y"),
            "plot_function": 'plot_up_down_dots',
            "value_pattern": re.compile("^(0|1|Up|Down)$")
        }
    }
